@@ -441,6 +441,8 @@ def load_content(url,targetfile,src_path,dest_path,additional_content,app_config
                         ngccontent.unzipFile(targetfile, "additional_content", src_path)
                     
     if app_config["additional_content"]["upload_content"]:
+        print("Uploading content locally on: {}".format(src_path))
+        print("To {} on datastore".format(dest_path))
         ngccontent.upload_data(
             ws,
             ws.get_default_datastore(),
